Macro handlebars::log [−][src]
This macro is defined if the logging feature is not set.
It ignores all logging calls inside the library.
This macro is defined if the logging feature is not set.
It ignores all logging calls inside the library.