Struct handlebars::PathAndJson [−][src]
pub struct PathAndJson<'reg: 'rc, 'rc> { /* fields omitted */ }Json wrapper that holds the Json value and reference path information
Methods
impl<'reg: 'rc, 'rc> PathAndJson<'reg, 'rc>[src]
impl<'reg: 'rc, 'rc> PathAndJson<'reg, 'rc>pub fn new(
path: Option<String>,
value: ScopedJson<'reg, 'rc>
) -> PathAndJson<'reg, 'rc>[src]
pub fn new(
path: Option<String>,
value: ScopedJson<'reg, 'rc>
) -> PathAndJson<'reg, 'rc>pub fn path(&self) -> Option<&String>[src]
pub fn path(&self) -> Option<&String>Returns relative path when the value is referenced
If the value is from a literal, the path is None
pub fn path_root(&self) -> Option<&str>[src]
pub fn path_root(&self) -> Option<&str>Return root level of this path if any
pub fn value(&self) -> &Json[src]
pub fn value(&self) -> &JsonReturns the value